@@ -7,16 +7,11 @@ import logging
 import re
 import string
 import warnings
+from collections.abc import Iterable, Iterator
 from functools import lru_cache
 from typing import (
     Any,
-    Dict,
-    Iterable,
-    Iterator,
-    List,
     Optional,
-    Tuple,
-    Type,
     TypeVar,
     Union,
 )
@@ -91,25 +86,25 @@ logger = logging.getLogger("moto")
 
 
 # List of supported CloudFormation models
-@lru_cache()
-def get_model_list() -> List[Type[CloudFormationModel]]:
+@lru_cache
+def get_model_list() -> list[type[CloudFormationModel]]:
     return CloudFormationModel.__subclasses__()
 
 
-@lru_cache()
-def get_model_map() -> Dict[str, Type[CloudFormationModel]]:
+@lru_cache
+def get_model_map() -> dict[str, type[CloudFormationModel]]:
     return {model.cloudformation_type(): model for model in get_model_list()}
 
 
-@lru_cache()
-def get_name_type_map() -> Dict[str, str]:
+@lru_cache
+def get_name_type_map() -> dict[str, str]:
     return {
         model.cloudformation_type(): model.cloudformation_name_type()
         for model in get_model_list()
     }
 
 
-class Output(object):
+class Output:
     def __init__(self, key: str, value: str, description: str):
         self.description = description
         self.key = key
@@ -119,7 +114,7 @@ class Output(object):
         return f'Output:"{self.key}"="{self.value}"'
 
 
-class LazyDict(Dict[str, Any]):
+class LazyDict(dict[str, Any]):
     def __getitem__(self, key: str) -> Any:
         val = dict.__getitem__(self, key)
         if callable(val):
@@ -276,7 +271,7 @@ def clean_json(resource_json: Any, resources_map: "ResourceMap") -> Any:
         return resource_json
 
 
-def resource_class_from_type(resource_type: str) -> Type[CloudFormationModel]:
+def resource_class_from_type(resource_type: str) -> type[CloudFormationModel]:
     if resource_type in NULL_MODELS:
         return None  # type: ignore[return-value]
     if resource_type.startswith("Custom::"):
@@ -322,13 +317,14 @@ def generate_resource_name(resource_type: str, stack_name: str, logical_id: str)
 
 
 def parse_resource(
-    resource_json: Dict[str, Any], resources_map: "ResourceMap"
-) -> Tuple[Type[CloudFormationModel], Any, str]:
+    resource_json: dict[str, Any], resources_map: "ResourceMap"
+) -> tuple[type[CloudFormationModel], Any, str]:
     resource_type = resource_json["Type"]
     resource_class = resource_class_from_type(resource_type)
     if not resource_class:
         warnings.warn(
-            f"Tried to parse {resource_type} but it's not supported by moto's CloudFormation implementation"
+            f"Tried to parse {resource_type} but it's not supported by moto's CloudFormation implementation",
+            stacklevel=2,
         )
         return None  # type: ignore[return-value]
 
@@ -341,9 +337,9 @@ def parse_resource(
 
 
 def parse_resource_and_generate_name(
-    logical_id: str, resource_json: Dict[str, Any], resources_map: "ResourceMap"
-) -> Tuple[Type[CloudFormationModel], Dict[str, Any], str]:
-    resource_tuple: Tuple[Type[CloudFormationModel], Dict[str, Any], str] = (
+    logical_id: str, resource_json: dict[str, Any], resources_map: "ResourceMap"
+) -> tuple[type[CloudFormationModel], dict[str, Any], str]:
+    resource_tuple: tuple[type[CloudFormationModel], dict[str, Any], str] = (
         parse_resource(resource_json, resources_map)
     )
     if not resource_tuple:
@@ -373,7 +369,7 @@ def parse_resource_and_generate_name(
 
 def parse_and_create_resource(
     logical_id: str,
-    resource_json: Dict[str, Any],
+    resource_json: dict[str, Any],
     resources_map: "ResourceMap",
     account_id: str,
     region_name: str,
@@ -384,7 +380,7 @@ def parse_and_create_resource(
         return None
 
     resource_type = resource_json["Type"]
-    resource_tuple: Tuple[Type[CloudFormationModel], Dict[str, Any], str] = (
+    resource_tuple: tuple[type[CloudFormationModel], dict[str, Any], str] = (
         parse_resource_and_generate_name(logical_id, resource_json, resources_map)
     )
     if not resource_tuple:
@@ -405,12 +401,12 @@ def parse_and_create_resource(
 
 def parse_and_update_resource(
     logical_id: str,
-    resource_json: Dict[str, Any],
+    resource_json: dict[str, Any],
     resources_map: "ResourceMap",
     account_id: str,
     region_name: str,
 ) -> Optional[CF_MODEL]:
-    resource_tuple: Optional[Tuple[Type[CloudFormationModel], Dict[str, Any], str]] = (
+    resource_tuple: Optional[tuple[type[CloudFormationModel], dict[str, Any], str]] = (
         parse_resource_and_generate_name(logical_id, resource_json, resources_map)
     )
     if not resource_tuple:
@@ -435,7 +431,7 @@ def parse_and_update_resource(
 
 
 def parse_and_delete_resource(
-    resource_name: str, resource_json: Dict[str, Any], account_id: str, region_name: str
+    resource_name: str, resource_json: dict[str, Any], account_id: str, region_name: str
 ) -> None:
     resource_type = resource_json["Type"]
     resource_class = resource_class_from_type(resource_type)
@@ -448,9 +444,9 @@ def parse_and_delete_resource(
 
 
 def parse_condition(  # type: ignore[return]
-    condition: Union[Dict[str, Any], bool],
+    condition: Union[dict[str, Any], bool],
     resources_map: "ResourceMap",
-    condition_map: Dict[str, Any],
+    condition_map: dict[str, Any],
 ) -> bool:
     if isinstance(condition, bool):
         return condition
@@ -473,17 +469,13 @@ def parse_condition(  # type: ignore[return]
         return not parse_condition(condition_values[0], resources_map, condition_map)
     elif condition_operator == "Fn::And":
         return all(
-            [
-                parse_condition(condition_value, resources_map, condition_map)
-                for condition_value in condition_values
-            ]
+            parse_condition(condition_value, resources_map, condition_map)
+            for condition_value in condition_values
         )
     elif condition_operator == "Fn::Or":
         return any(
-            [
-                parse_condition(condition_value, resources_map, condition_map)
-                for condition_value in condition_values
-            ]
+            parse_condition(condition_value, resources_map, condition_map)
+            for condition_value in condition_values
         )
 
 
@@ -506,7 +498,7 @@ def parse_output(
     return output
 
 
-def get_references_from_template(template: Dict[str, Any]) -> List[str]:
+def get_references_from_template(template: dict[str, Any]) -> list[str]:
     references = []
     if isinstance(template, dict):
         for key in template:
@@ -531,27 +523,27 @@ class ResourceMap(collections_abc.Mapping):  # type: ignore[type-arg]
         self,
         stack_id: str,
         stack_name: str,
-        parameters: Dict[str, Any],
-        tags: Dict[str, Any],
+        parameters: dict[str, Any],
+        tags: dict[str, Any],
         region_name: str,
         account_id: str,
-        template: Dict[str, Any],
-        cross_stack_resources: Optional[Dict[str, "Export"]],
+        template: dict[str, Any],
+        cross_stack_resources: Optional[dict[str, "Export"]],
     ):
         self._template = template
-        self._resource_json_map: Dict[str, Any] = (
+        self._resource_json_map: dict[str, Any] = (
             template["Resources"] if template != {} else {}
         )
         self._account_id = account_id
         self._region_name = region_name
         self.input_parameters = parameters
         self.tags = copy.deepcopy(tags)
-        self.resolved_parameters: Dict[str, Any] = {}
+        self.resolved_parameters: dict[str, Any] = {}
         self.cross_stack_resources = cross_stack_resources
         self.stack_id = stack_id
 
         # Create the default resources
-        self._parsed_resources: Dict[str, Any] = {
+        self._parsed_resources: dict[str, Any] = {
             "AWS::AccountId": account_id,
             "AWS::Region": self._region_name,
             "AWS::StackId": stack_id,
@@ -588,7 +580,7 @@ class ResourceMap(collections_abc.Mapping):  # type: ignore[type-arg]
     def __len__(self) -> int:
         return len(self._resource_json_map)
 
-    def __get_resources_in_dependency_order(self) -> List[str]:
+    def __get_resources_in_dependency_order(self) -> list[str]:
         resource_map = copy.deepcopy(self._resource_json_map)
         resources_in_dependency_order = []
 
@@ -747,7 +739,7 @@ class ResourceMap(collections_abc.Mapping):  # type: ignore[type-arg]
         self.load_conditions()
         self.validate_outputs()
 
-    def create(self, template: Dict[str, Any]) -> bool:
+    def create(self, template: dict[str, Any]) -> bool:
         # Since this is a lazy map, to create every object we just need to
         # iterate through self.
         # Assumes that self.load() has been called before
@@ -780,9 +772,9 @@ class ResourceMap(collections_abc.Mapping):  # type: ignore[type-arg]
 
     def build_resource_diff(
         self,
-        other_template: Dict[str, Any],
-        parameters: Optional[Dict[str, Any]] = None,
-    ) -> Dict[str, Any]:
+        other_template: dict[str, Any],
+        parameters: Optional[dict[str, Any]] = None,
+    ) -> dict[str, Any]:
         old = self._resource_json_map
         new = other_template["Resources"]
 
@@ -807,11 +799,11 @@ class ResourceMap(collections_abc.Mapping):  # type: ignore[type-arg]
         return resource_names_by_action
 
     def build_change_set_actions(
-        self, template: Dict[str, Any]
-    ) -> Dict[str, Dict[str, Dict[str, str]]]:
+        self, template: dict[str, Any]
+    ) -> dict[str, dict[str, dict[str, str]]]:
         resource_names_by_action = self.build_resource_diff(template)
 
-        resources_by_action: Dict[str, Dict[str, Dict[str, str]]] = {
+        resources_by_action: dict[str, dict[str, dict[str, str]]] = {
             "Add": {},
             "Modify": {},
             "Remove": {},
@@ -838,7 +830,7 @@ class ResourceMap(collections_abc.Mapping):  # type: ignore[type-arg]
         return resources_by_action
 
     def update(
-        self, template: Dict[str, Any], parameters: Optional[Dict[str, Any]] = None
+        self, template: dict[str, Any], parameters: Optional[dict[str, Any]] = None
     ) -> None:
         resource_names_by_action = self.build_resource_diff(template, parameters)
 
@@ -853,7 +845,8 @@ class ResourceMap(collections_abc.Mapping):  # type: ignore[type-arg]
                     else:
                         # Resource wasn't created in the first place
                         warnings.warn(
-                            f"Unable to delete {logical_name}, as it was never created"
+                            f"Unable to delete {logical_name}, as it was never created",
+                            stacklevel=2,
                         )
                 except Exception as e:
                     # skip over dependency violations, and try again in another pass
@@ -903,11 +896,11 @@ class ResourceMap(collections_abc.Mapping):  # type: ignore[type-arg]
 
     def delete(self) -> None:
         # Only try to delete resources without a Retain DeletionPolicy
-        remaining_resources = set(
+        remaining_resources = {
             key
             for key, value in self._resource_json_map.items()
             if not value.get("DeletionPolicy") == "Retain"
-        )
+        }
         # Keep track of how many resources we deleted before
         # (set to current + 1 to pretend the number of resources is already going down)
         previous_remaining_resources = len(remaining_resources) + 1
@@ -942,7 +935,7 @@ class ResourceMap(collections_abc.Mapping):  # type: ignore[type-arg]
             raise last_exception
 
     def _delete_resource(
-        self, parsed_resource: Any, resource_json: Dict[str, Any]
+        self, parsed_resource: Any, resource_json: dict[str, Any]
     ) -> None:
         try:
             parsed_resource.delete(self._account_id, self._region_name)
@@ -961,7 +954,7 @@ class ResourceMap(collections_abc.Mapping):  # type: ignore[type-arg]
 
 
 class OutputMap(collections_abc.Mapping):  # type: ignore[type-arg]
-    def __init__(self, resources: ResourceMap, template: Dict[str, Any], stack_id: str):
+    def __init__(self, resources: ResourceMap, template: dict[str, Any], stack_id: str):
         self._template = template
         self._stack_id = stack_id
 
@@ -971,11 +964,11 @@ class OutputMap(collections_abc.Mapping):  # type: ignore[type-arg]
                 message="[/Outputs] 'null' values are not allowed in templates",
             )
 
-        self._output_json_map: Dict[str, Any] = template.get("Outputs")  # type: ignore[assignment]
+        self._output_json_map: dict[str, Any] = template.get("Outputs")  # type: ignore[assignment]
 
         # Create the default resources
         self._resource_map = resources
-        self._parsed_outputs: Dict[str, Output] = dict()
+        self._parsed_outputs: dict[str, Output] = {}
 
     def __getitem__(self, key: str) -> Optional[Output]:
         output_logical_id = key
@@ -1002,7 +995,7 @@ class OutputMap(collections_abc.Mapping):  # type: ignore[type-arg]
         return self._output_json_map.keys() if self._output_json_map else []
 
     @property
-    def exports(self) -> List["Export"]:
+    def exports(self) -> list["Export"]:
         exports = []
         if self.outputs:
             for value in self._output_json_map.values():
@@ -1015,7 +1008,7 @@ class OutputMap(collections_abc.Mapping):  # type: ignore[type-arg]
         return exports
 
 
-class Export(object):
+class Export:
     def __init__(self, exporting_stack_id: str, name: str, value: str):
         self._exporting_stack_id = exporting_stack_id
         self._name = name
