@@ -57,12 +57,11 @@ import base64
 import calendar
 import json
 from collections import namedtuple
-from collections.abc import Generator, Mapping, MutableMapping
+from collections.abc import Callable, Generator, Mapping, MutableMapping
 from dataclasses import dataclass
 from datetime import datetime
 from typing import (
     Any,
-    Callable,
     Optional,
     TypedDict,
     Union,
@@ -100,11 +99,13 @@ class SerializationContext:
 
 class TimestampSerializer:
     TIMESTAMP_FORMAT_ISO8601 = "iso8601"
+    TIMESTAMP_FORMAT_ISO8601_ZEROED = "iso8601_zeroed"
     TIMESTAMP_FORMAT_RFC822 = "rfc822"
     TIMESTAMP_FORMAT_UNIX = "unixtimestamp"
 
     ISO8601 = "%Y-%m-%dT%H:%M:%SZ"
     ISO8601_MICRO = "%Y-%m-%dT%H:%M:%S.%fZ"
+    ISO8601_MICRO_ZEROED = "%Y-%m-%dT%H:%M:%S.000Z"
 
     def __init__(self, default_format: str) -> None:
         self.default_format = default_format
@@ -125,6 +126,9 @@ class TimestampSerializer:
             timestamp_format = self.ISO8601
         return value.strftime(timestamp_format)
 
+    def _timestamp_iso8601_zeroed(self, value: datetime) -> str:
+        return value.strftime(self.ISO8601_MICRO_ZEROED)
+
     @staticmethod
     def _timestamp_unixtimestamp(value: datetime) -> float:
         return int(calendar.timegm(value.timetuple()))
@@ -888,6 +892,8 @@ class QueryJSONSerializer(QuerySerializer):
 
 
 class EC2Serializer(QuerySerializer):
+    DEFAULT_TIMESTAMP_FORMAT = TimestampSerializer.TIMESTAMP_FORMAT_ISO8601_ZEROED
+
     def _serialize_body(self, body: Mapping[str, Any]) -> str:
         body_serialized = xmltodict.unparse(
             body,
