@@ -787,10 +787,27 @@ class InvalidLaunchTemplateNameNotFoundWithNameError(EC2ClientError):
     def __init__(self, name: str):
         super().__init__(
             "InvalidLaunchTemplateName.NotFoundException",
-            f"The specified launch template, with template name {name}, does not exist",
+            f"The specified launch template, with template name {name}, does not exist.",
         )
 
 
+class InvalidLaunchTemplateIdNotFound(EC2ClientError):
+    def __init__(self, template_id: str):
+        super().__init__(
+            "InvalidLaunchTemplateId.NotFound",
+            f"The specified launch template, with template ID {template_id}, does not exist.",
+        )
+
+
+class InvalidLaunchTemplateVersionNotFound(EC2ClientError):
+    def __init__(self, version: str, template_id: Optional[str] = None):
+        if template_id:
+            msg = f"Could not find the specified version {version} for the launch template with ID {template_id}."
+        else:
+            msg = f"The launch template version {version} is not found for the specified launch template."
+        super().__init__("InvalidLaunchTemplateId.VersionNotFound", msg)
+
+
 class InvalidParameterDependency(EC2ClientError):
     def __init__(self, param: str, param_needed: str):
         super().__init__(
