@@ -6,9 +6,9 @@ from moto.core.exceptions import JsonRESTError
 class ResourceNotFoundException(JsonRESTError):
     code = 400
 
-    def __init__(self, resource: str):
+    def __init__(self, resource: str, resource_type: str = "Application"):
         super().__init__(
-            "ResourceNotFoundException", f"Application {resource} does not exist"
+            "ResourceNotFoundException", f"{resource_type} {resource} does not exist"
         )
 
 
@@ -17,3 +17,10 @@ class ValidationException(JsonRESTError):
 
     def __init__(self, message: str):
         super().__init__("ValidationException", message)
+
+
+class AccessDeniedException(JsonRESTError):
+    code = 400
+
+    def __init__(self, message: str):
+        super().__init__("AccessDeniedException", message)
