@@ -1,6 +1,7 @@
 import json
 import re
-from typing import Any, Callable, Optional
+from collections.abc import Callable
+from typing import Any, Optional
 
 from moto.core.responses import BaseResponse
 
