@@ -16,8 +16,10 @@ class IntervalSecondsDecl(EvalComponent):
     def __init__(self, seconds: int = DEFAULT_SECONDS):
         if not (1 <= seconds <= IntervalSecondsDecl.MAX_VALUE):
             raise ValueError(
-                f"IntervalSeconds value MUST be a positive integer between 1 and {IntervalSecondsDecl.MAX_VALUE}, got '{seconds}'."
+                f"IntervalSeconds value MUST be a positive integer between "
+                f"1 and {IntervalSecondsDecl.MAX_VALUE}, got '{seconds}'."
             )
+
         self.seconds: Final[int] = seconds
 
     def _eval_body(self, env: Environment) -> None:
