@@ -1,3 +1,5 @@
+from typing import Any
+
 import boto3
 from botocore.client import BaseClient
 from botocore.config import Config
@@ -9,13 +11,15 @@ from moto.stepfunctions.parser.asl.component.common.timeouts.timeout import (
 )
 
 
-def boto_client_for(region: str, account: str, service: str) -> BaseClient:
+def boto_client_for(
+    region: str, service: str, state_credentials: Any = None
+) -> BaseClient:
     intercepting_boto_calls = botocore_stubber.enabled
     kwargs = {}
     if not intercepting_boto_calls:
         kwargs["endpoint_url"] = f"http://localhost:{moto_server_port()}"
     return boto3.client(
-        aws_access_key_id=account,
+        aws_access_key_id="ak",
         region_name=region,
         service_name=service,
         aws_secret_access_key="sk",
